==> scipion-em-flexutils-3.1.0.tar.gz: scipion-em-flexutils-3.1.0/flexutils/protocols/__init__.py <==
# -*- coding: utf-8 -*-
# **************************************************************************
# *
# * Authors:     David Herreros Calero (dherreros@cnb.csic.es)
# *
# * Unidad de  Bioinformatica of Centro Nacional de Biotecnologia , CSIC
# *
# * This program is free software; you can redistribute it and/or modify
# * it under the terms of the GNU General Public License as published by
# * the Free Software Foundation; either version 2 of the License, or
# * (at your option) any later version.
# *
# * This program is distributed in the hope that it will be useful,
# * but WITHOUT ANY WARRANTY; without even the implied warranty of
# * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# * GNU General Public License for more details.
# *
# * You should have received a copy of the GNU General Public License
# * along with this program; if not, write to the Free Software
# * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
# * 02111-1307  USA
# *
# *  All comments concerning this program package may be sent to the
# *  e-mail address 'scipion@cnb.csic.es'
# *
# **************************************************************************
from .protocol_base import ProtFlexBase

from .protocol_select_views import ProtFlexSelectViews
from .protocol_annotate_space import ProtFlexAnnotateSpace
from .protocol_auto_reference import ProtFlexAutoReference
from .protocol_dimred import ProtFlexDimRedSpace
from .protocol_find_optimal_clusters import ProtFlexOptimalClusters
from .protocol_associate_flex_space_to_particles import ProtFlexAssociateSpace
from .protocol_score_landscape import ProtFlexScoreLandscape

# Zernike3D Xmipp protocols (offered here due to strong package dependency)
from .xmipp import *

==> scipion-em-flexutils-3.1.5.tar.gz: scipion-em-flexutils-3.1.5/flexutils/protocols/__init__.py <==
# -*- coding: utf-8 -*-
# **************************************************************************
# *
# * Authors:     David Herreros Calero (dherreros@cnb.csic.es)
# *
# * Unidad de  Bioinformatica of Centro Nacional de Biotecnologia , CSIC
# *
# * This program is free software; you can redistribute it and/or modify
# * it under the terms of the GNU General Public License as published by
# * the Free Software Foundation; either version 2 of the License, or
# * (at your option) any later version.
# *
# * This program is distributed in the hope that it will be useful,
# * but WITHOUT ANY WARRANTY; without even the implied warranty of
# * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# * GNU General Public License for more details.
# *
# * You should have received a copy of the GNU General Public License
# * along with this program; if not, write to the Free Software
# * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
# * 02111-1307  USA
# *
# *  All comments concerning this program package may be sent to the
# *  e-mail address 'scipion@cnb.csic.es'
# *
# **************************************************************************

from .protocol_select_views import ProtFlexSelectViews
from .protocol_annotate_space import ProtFlexAnnotateSpace
from .protocol_auto_reference import ProtFlexAutoReference
from .protocol_dimred import ProtFlexDimRedSpace
from .protocol_find_optimal_clusters import ProtFlexOptimalClusters
from .protocol_associate_flex_space_to_particles import ProtFlexAssociateSpace
from .protocol_score_landscape import ProtFlexScoreLandscape
from .protocol_order_volumes import ProtFlexOrderVolumes
from .protocol_filter_pca import ProtFlexFilterPCA

# Zernike3D Xmipp protocols (offered here due to strong package dependency)
from .xmipp import *
